/**
 * This file is part of pppBenchmark, a program accompanying
 * the paper: Abeel, T, Van de Peer Y, Saeys Y.  2009.  Towards a gold standard for promoter prediction evaluation. Bioinformatics. 25(12):i313-i320.
    * 
 * Copyright 2009 Thomas Abeel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 */
package be.abeel.pppbenchmark;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import be.abeel.io.LineIterator;
import be.abeel.io.LineIteratorFactory;

public abstract class Protocol {

	public List<Map<Double, int[]>> analyze(File pred) throws Exception {
		List<Map<Double, int[]>> arr = new ArrayList<Map<Double, int[]>>();
		for (String chr : Config.chrs) {

			arr.add(run(chr, it(pred)));
		}
		return arr;

	}

	private LineIterator it(File file) throws IOException {
		if (file.getName().endsWith(".gz")) {
//			System.out.println("GZIPPED");
			return LineIteratorFactory.createFromGZip(file);
		} else {
//			System.out.println("plain");
			return new LineIterator(file);
		}
	}

	public abstract Map<Double, int[]> run(String chr, LineIterator pred) throws Exception;
}
